@@ -7,7 +7,7 @@ use vars qw( @ISA $VERSION );
 
 my $gen = undef;
 @ISA = qw( DynaLoader );
-$VERSION = '1.15';
+$VERSION = '1.17';
 
 bootstrap Math::Random::MT $VERSION;
 
@@ -25,7 +25,7 @@ sub set_seed
 {
     my ($self, @seeds) = @_;
     @seeds > 1 ? $self->setup_array(@seeds) :
-                 $self->init_seed($seeds[0] || _rand_seed());
+                 $self->init_seed(defined $seeds[0] ? $seeds[0] : _rand_seed());
     return $self->get_seed;
 }
 
@@ -40,27 +40,28 @@ sub rand
 {
     my ($self, $N) = @_;
 
-    unless (ref $self) {
-        Math::Random::MT::srand() unless defined $gen;
-        $self = $gen;
-    }
-
-    return $self->genrand();
-}
-
-sub irand
-{
-    my ($self, $N) = @_;
-
     unless (ref $self) {
         $N = $self;
         Math::Random::MT::srand() unless defined $gen;
         $self = $gen;
     }
 
-    return ($N || 1) * $self->genirand();
+    return ($N || 1) * $self->genrand();
 }
 
+sub irand
+{
+    my ($self) = @_;
+
+    unless (ref $self) {
+        Math::Random::MT::srand() unless defined $gen;
+        $self = $gen;
+    }
+
+    return $self->genirand();
+}
+
+
 # Generate a random seed using the built-in PRNG.
 
 sub _rand_seed {
@@ -140,7 +141,8 @@ Creates a new generator seeded with an array of (up to 624) unsigned
 
 =item set_seed()
 
-Seeds the generator. It takes the same arguments as I<new()>.
+Seeds the generator and returns the seed used. It takes the same arguments as
+I<new()>.
 
 =item get_seed()
 
